@@ -80,6 +80,11 @@ const char *srmConnectorGetModel(SRMConnector *connector)
     return connector->model ? connector->model : "Unknown";
 }
 
+const char *srmConnectorGetSerial(SRMConnector *connector)
+{
+    return connector->serial;
+}
+
 SRMList *srmConnectorGetEncoders(SRMConnector *connector)
 {
     return connector->encoders;
@@ -360,6 +365,9 @@ fail:
 
 UInt8 srmConnectorRepaint(SRMConnector *connector)
 {
+    if (connector->lockCurrentBuffer)
+        return 0;
+
     if (connector->state == SRM_CONNECTOR_STATE_INITIALIZING ||
         connector->state == SRM_CONNECTOR_STATE_INITIALIZED ||
         connector->state == SRM_CONNECTOR_STATE_CHANGING_MODE)
@@ -401,6 +409,19 @@ void srmConnectorUninitialize(SRMConnector *connector)
     SRMDebug("[%s] [%s] Uninitialized.", connector->device->shortName, connector->name);
 }
 
+UInt32 srmConnectorGetCurrentBufferAge(SRMConnector *connector)
+{
+    if (connector->state != SRM_CONNECTOR_STATE_INITIALIZED)
+        return 0;
+
+    UInt32 num = srmConnectorGetBuffersCount(connector);
+
+    if (connector->bufferAgeFrame >= num)
+        return num;
+
+    return 0;
+}
+
 UInt32 srmConnectorGetCurrentBufferIndex(SRMConnector *connector)
 {
     if (connector->state != SRM_CONNECTOR_STATE_INITIALIZED)
@@ -958,3 +979,18 @@ EGLContext srmConnectorGetContext(SRMConnector *connector)
 
     return connector->renderInterface.getEGLContext(connector);
 }
+
+UInt8 srmConnectorIsNonDesktop(SRMConnector *connector)
+{
+    return connector->nonDesktop;
+}
+
+void srmConnectorSetCurrentBufferLocked(SRMConnector *connector, UInt8 locked)
+{
+    connector->lockCurrentBuffer = locked;
+}
+
+UInt8 srmConnectorIsCurrentBufferLocked(SRMConnector *connector)
+{
+    return connector->lockCurrentBuffer;
+}
