@@ -207,40 +207,38 @@ UInt32 srmConnectorGetType(SRMConnector *connector);
 /**
  * @brief Get the name of the connector.
  *
- * This function returns the name of the connector. The name is always unique, even across devices.
- * For example, if there are two **HDMI-A** connectors, one will be called **HDMI-A-0**, and the other **HDMI-A-1**.
+ * The name is always unique, even across devices but could change after a reboot.
  *
- * @param connector Pointer to the @ref SRMConnector for which to retrieve the name.
- * @return The name of the connector.
+ * @return The name of the connector, e.g. HDMI-A-1 or "Unknown" if not available.
  */
 const char *srmConnectorGetName(SRMConnector *connector);
 
 /**
- * @brief Get the manufacturer of the connector.
+ * @brief Get the manufacturer of the connected display.
  *
- * This function returns the manufacturer of the connector.
- *
- * @param connector Pointer to the @ref SRMConnector for which to retrieve the manufacturer.
- * @return The manufacturer of the connector.
+ * @return The manufacturer name or "Unknown" if not available.
  */
 const char *srmConnectorGetManufacturer(SRMConnector *connector);
 
 /**
- * @brief Get the model of the connector.
+ * @brief Get the model of the connected display.
  *
- * This function returns the model of the connector.
- *
- * @param connector Pointer to the @ref SRMConnector for which to retrieve the model.
- * @return The model of the connector.
+ * @return The model name or "Unknown" if not available.
  */
 const char *srmConnectorGetModel(SRMConnector *connector);
 
+/**
+ * @brief Get the serial number of the connected display.
+ *
+ * @note The serial number is unique and persistent across reboots.
+ *
+ * @return The serial number of the connected display or `NULL` if not available.
+ */
+const char *srmConnectorGetSerial(SRMConnector *connector);
+
 /**
  * @brief Get a list of available connector encoders.
  *
- * This function returns a list of available encoders for the given @ref SRMConnector.
- *
- * @param connector Pointer to the @ref SRMConnector for which to retrieve the encoders.
  * @return A list of available connector encoders (@ref SRMEncoder).
  */
 SRMList *srmConnectorGetEncoders(SRMConnector *connector);
@@ -291,16 +289,6 @@ UInt8 srmConnectorSetCursor(SRMConnector *connector, UInt8 *pixels);
  */
 UInt8 srmConnectorSetCursorPos(SRMConnector *connector, Int32 x, Int32 y);
 
-/**
- * @brief Get the model of the connector.
- *
- * This function returns the model of the connector.
- *
- * @param connector Pointer to the @ref SRMConnector for which to retrieve the model.
- * @return The model of the connector.
- */
-const char *srmConnectorGetModel(SRMConnector *connector);
-
 /**
  * @brief Get a list of available connector encoders.
  *
@@ -457,7 +445,7 @@ UInt8 srmConnectorInitialize(SRMConnector *connector, SRMConnectorInterface *int
  * After each `paintGL()` event, this method must be called again to schedule a new frame.
  *
  * @param connector Pointer to the @ref SRMConnector to schedule a new rendering frame.
- * @return 1 if scheduling is successful, 0 if an error occurs.
+ * @return 1 if scheduling is successful, 0 otherwise.
  *
  * @note This function triggers paintGL() and pageFlipped() events in the rendering process.
  */
@@ -510,6 +498,15 @@ UInt32 srmConnectorGetFramebufferID(SRMConnector *connector);
  */
 EGLContext srmConnectorGetContext(SRMConnector *connector);
 
+/**
+ * @brief Retrieves the age of the current buffer.
+ *
+ * This function returns the age of the buffer as specified in the
+ * [EGL_EXT_buffer_age](https://registry.khronos.org/EGL/extensions/EXT/EGL_EXT_buffer_age.txt)
+ * extension specification.
+ */
+UInt32 srmConnectorGetCurrentBufferAge(SRMConnector *connector);
+
 /**
  * @brief Returns the current framebuffer index.
  *
@@ -780,6 +777,35 @@ SRM_CONNECTOR_CONTENT_TYPE srmConnectorGetContentType(SRMConnector *connector);
  */
 UInt8 srmConnectorSetCustomScanoutBuffer(SRMConnector *connector, SRMBuffer *buffer);
 
+/**
+ * @brief Checks if the connector is not intended for desktop usage.
+ *
+ * Some connectors, such as VR headsets, set this property to 1 to indicate they are not meant for desktop use.
+ *
+ * @return 1 if not meant for desktop usage, 0 if meant for desktop or if disconnected.
+ */
+UInt8 srmConnectorIsNonDesktop(SRMConnector *connector);
+
+/**
+ * @brief Locks the buffer currently being displayed and ignores srmConnectorRepaint() calls.
+ *
+ * When set to 1, no `paintGL()` or `pageFlipped()` events are triggered. The default value is 0.
+ *
+ * @param connector The @ref SRMConnector instance.
+ * @param locked    A value of 1 locks the current buffer, 0 unlocks it.
+ */
+void srmConnectorSetCurrentBufferLocked(SRMConnector *connector, UInt8 locked);
+
+/**
+ * @brief Retrieves the locked state of the current buffer.
+ *
+ * @see srmConnectorSetCurrentBufferLocked()
+ *
+ * @param connector The @ref SRMConnector instance.
+ * @return          A value of 1 indicates the current buffer is locked, 0 indicates it is unlocked.
+ */
+UInt8 srmConnectorIsCurrentBufferLocked(SRMConnector *connector);
+
 /**
  * @}
  */
