@@ -112,7 +112,10 @@ UInt8 srmConnectorUpdateProperties(SRMConnector *connector)
         else if (strcmp(prop->name, "link-status") == 0)
             connector->propIDs.link_status = prop->prop_id;
         else if (strcmp(prop->name, "non-desktop") == 0)
+        {
             connector->propIDs.non_desktop = prop->prop_id;
+            connector->nonDesktop = props->prop_values[i] == 1;
+        }
         else if (strcmp(prop->name, "content type") == 0)
             connector->propIDs.content_type = prop->prop_id;
         else if (strcmp(prop->name, "panel orientation") == 0)
@@ -188,6 +191,7 @@ UInt8 srmConnectorUpdateNames(SRMConnector *connector)
 
     connector->manufacturer = di_info_get_make(info);
     connector->model = di_info_get_model(info);
+    connector->serial = di_info_get_serial(info);
     di_info_destroy(info);
     drmModeFreePropertyBlob(blob);
     drmModeFreeConnector(connectorRes);
@@ -213,6 +217,12 @@ void srmConnectorDestroyNames(SRMConnector *connector)
         free(connector->model);
         connector->model = NULL;
     }
+
+    if (connector->serial)
+    {
+        free(connector->serial);
+        connector->serial = NULL;
+    }
 }
 
 UInt8 srmConnectorUpdateEncoders(SRMConnector *connector)
@@ -240,7 +250,6 @@ UInt8 srmConnectorUpdateEncoders(SRMConnector *connector)
     }
 
     drmModeFreeConnector(connectorRes);
-
     return 1;
 }
 
@@ -434,7 +443,7 @@ void *srmConnectorRenderThread(void *conn)
         connector->hasRepaintCond = 1;
 
     connector->pendingPageFlip = 0;
-
+    connector->bufferAgeFrame = 0;
     connector->drmEventCtx.version = DRM_EVENT_CONTEXT_VERSION,
     connector->drmEventCtx.vblank_handler = NULL,
     connector->drmEventCtx.page_flip_handler = &srmRenderModeCommonPageFlipHandler,
@@ -494,6 +503,11 @@ void *srmConnectorRenderThread(void *conn)
 
         pthread_mutex_lock(&connector->stateMutex);
 
+paintGLChangedLockCurrentBuffer:
+
+        if (connector->lockCurrentBuffer)
+            connector->repaintRequested = 0;
+
         if (connector->state == SRM_CONNECTOR_STATE_INITIALIZED)
         {
             if (connector->repaintRequested)
@@ -504,17 +518,26 @@ void *srmConnectorRenderThread(void *conn)
                     connector->renderInterface.render(connector);
                     connector->inPaintGL = 0;
 
+                    if (connector->lockCurrentBuffer)
+                        goto paintGLChangedLockCurrentBuffer;
+
                     /* Scanning out a custom user buffer (skip the render mode interface) */
                     if (connector->userScanoutBufferRef[0])
                     {
+                        connector->bufferAgeFrame = 0;
                         srmRenderModeCommonDestroySync(connector);
                         srmRenderModeCommonPageFlip(connector, connector->userScanoutBufferRef[0]->scanout.fb);
                         connector->interface->pageFlipped(connector, connector->interfaceData);
                     }
                     /* Normal connector rendering */
                     else
+                    {
                         connector->renderInterface.flipPage(connector);
 
+                        if (connector->bufferAgeFrame < connector->renderInterface.getBuffersCount(connector))
+                            connector->bufferAgeFrame++;
+                    }
+
                     /* Release previous custom scanout buffer if any */
                     if (connector->userScanoutBufferRef[0] || connector->userScanoutBufferRef[1])
                     {
@@ -536,6 +559,8 @@ void *srmConnectorRenderThread(void *conn)
         {
             SRMWarning("[connector] Changing mode started.");
 
+            connector->bufferAgeFrame = 0;
+
             if (connector->renderInterface.updateMode(connector))
             {
                 connector->state = SRM_CONNECTOR_STATE_INITIALIZED;
@@ -563,6 +588,7 @@ void *srmConnectorRenderThread(void *conn)
         else if (connector->state == SRM_CONNECTOR_STATE_RESUMING)
         {
             connector->state = SRM_CONNECTOR_STATE_INITIALIZED;
+            connector->bufferAgeFrame = 0;
             connector->renderInterface.resume(connector);
             pthread_mutex_unlock(&connector->stateMutex);
             usleep(1000);
