@@ -53,6 +53,7 @@ struct SRMConnectorStruct
     SRMDevice *device;
     SRMListItem *deviceLink;
     struct SRMConnectorPropIDs propIDs;
+    UInt8 nonDesktop;
     SRMList *encoders, *modes;
     UInt32 mmWidth, mmHeight;
     SRM_CONNECTOR_SUBPIXEL subpixel;
@@ -95,6 +96,7 @@ struct SRMConnectorStruct
     drmEventContext drmEventCtx;
     UInt8 pendingPageFlip;
     UInt8 firstPageFlip;
+    UInt32 bufferAgeFrame;
 
     // Sync
     Int32 fenceFD;
@@ -105,6 +107,7 @@ struct SRMConnectorStruct
     UInt8 hasRepaintMutex;
     pthread_mutex_t repaintMutex;
 
+    UInt8 lockCurrentBuffer;
     UInt8 repaintRequested;
     pthread_mutex_t stateMutex;
     SRMBox *damageBoxes;
